Fire Dynamics Tools
===================

General fire dynamics tools and calculations.

These tools are published by the U.S. Nuclear Regulatory Commission (U.S. NRC) and available at: https://www.nrc.gov/reading-rm/doc-collections/nuregs/staff/sr1805/s1/index

.. automodule:: ofire.fire_dynamics_tools
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 2 
----------------------------------------------------------------------------------------------------------------------------

.. automodule:: ofire.fire_dynamics_tools.chapter_2
   :members:
   :undoc-members:
   :show-inheritance:

Equation Modules
~~~~~~~~~~~~~~~~

Equation 2.1 - Hot Gas Temperature Increase (MQH Method)
""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_2.equation_2_1
   :members:
   :undoc-members:
   :show-inheritance:

Equation 2.2 - Compartment Interior Surface Area
"""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_2.equation_2_2
   :members:
   :undoc-members:
   :show-inheritance:

Equation 2.3 - Heat Transfer Coefficient (Long Times/Thin Walls)
"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_2.equation_2_3
   :members:
   :undoc-members:
   :show-inheritance:

Equation 2.4 - Thermal Penetration Time
""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_2.equation_2_4
   :members:
   :undoc-members:
   :show-inheritance:

Equation 2.5 - Heat Transfer Coefficient (Short Times/Thick Walls)
""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_2.equation_2_5
   :members:
   :undoc-members:
   :show-inheritance:

Equation 2.6 - Hot Gas Temperature Increase (Beyler Closed Compartment)
"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_2.equation_2_6
   :members:
   :undoc-members:
   :show-inheritance:

Equation 2.7 - Nondimensional Hot Gas Temperature Increase (FPA)
"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_2.equation_2_7
   :members:
   :undoc-members:
   :show-inheritance:

Equation 2.8 - Hot Gas Temperature Increase (Deal and Beyler)
"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_2.equation_2_8
   :members:
   :undoc-members:
   :show-inheritance:

Equation 2.9 - Convective Heat Transfer Coefficient
""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_2.equation_2_9
   :members:
   :undoc-members:
   :show-inheritance:

Equation 2.10 - Smoke Layer Interface Height (Yamana-Tanaka)
"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_2.equation_2_10
   :members:
   :undoc-members:
   :show-inheritance:

Equation 2.11 - K Constant for Smoke Layer Height (Yamana-Tanaka)
""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_2.equation_2_11
   :members:
   :undoc-members:
   :show-inheritance:

Equation 2.12 - K Constant for Smoke Layer Height (Simplified)
"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_2.equation_2_12
   :members:
   :undoc-members:
   :show-inheritance:

Equation 2.13 - Hot Gas Density
""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_2.equation_2_13
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 4
---------

.. automodule:: ofire.fire_dynamics_tools.chapter_4
   :members:
   :undoc-members:
   :show-inheritance:

Equation Modules
~~~~~~~~~~~~~~~~

Equation 4.1 - Wall Fire Flame Height
""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_4.equation_4_1
   :members:
   :undoc-members:
   :show-inheritance:

Equation 4.2 - Line Fire Flame Height
""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_4.equation_4_2
   :members:
   :undoc-members:
   :show-inheritance:

Equation 4.3 - Corner Fire Flame Height
""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_4.equation_4_3
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 5
---------

.. automodule:: ofire.fire_dynamics_tools.chapter_5
   :members:
   :undoc-members:
   :show-inheritance:

Equation Modules
~~~~~~~~~~~~~~~~

Equation 5.1 - Thermal Radiation from a Point Source
"""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_5.equation_5_1
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 9
---------

.. automodule:: ofire.fire_dynamics_tools.chapter_9
   :members:
   :undoc-members:
   :show-inheritance:

Equation Modules
~~~~~~~~~~~~~~~~

Equation 9.2 - Maximum Centerline Temperature Rise in Fire Plumes
""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_9.equation_9_2
   :members:
   :undoc-members:
   :show-inheritance:

Equation 9.3 - Virtual Origin Height to Diameter Ratio
"""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_9.equation_9_3
   :members:
   :undoc-members:
   :show-inheritance:

Equation 9.4 - Effective Diameter of a Fire Source
"""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_9.equation_9_4
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 18
----------

.. automodule:: ofire.fire_dynamics_tools.chapter_18
   :members:
   :undoc-members:
   :show-inheritance:

Equation Modules
~~~~~~~~~~~~~~~~

Equation 18.1 - Visibility Through Smoke
"""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_18.equation_18_1
   :members:
   :undoc-members:
   :show-inheritance:

Equation 18.2 - Mass Concentration of Particulates
"""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_18.equation_18_2
   :members:
   :undoc-members:
   :show-inheritance:

Equation 18.3 - Mass of Particulates Produced
""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.fire_dynamics_tools.chapter_18.equation_18_3
   :members:
   :undoc-members:
   :show-inheritance: